# ConnectorUpstreamStatsPublish

Published upstream statistics for a connector instance

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_totals** | [**ApplicationServiceCommonStats**](ApplicationServiceCommonStats.md) |  | 
**ip_upstream_stats** | [**[ApplicationServiceStatsPublish]**](ApplicationServiceStatsPublish.md) | The stats for all ip upstreams of a connector instance.  | 
**ssh_upstream_stats** | [**[ApplicationServiceStatsPublish]**](ApplicationServiceStatsPublish.md) | The stats for all ssh upstreams of a connector instance.  | 
**desktop_upstream_stats** | [**[ApplicationServiceStatsPublish]**](ApplicationServiceStatsPublish.md) | The stats for all desktop upstreams of a connector instance.  | 
**share_upstream_stats** | [**[ApplicationServiceStatsPublish]**](ApplicationServiceStatsPublish.md) | The stats for all share upstreams of a connector instance.  | 
**database_upstream_stats** | [**[ApplicationServiceStatsPublish]**](ApplicationServiceStatsPublish.md) | The stats for all database upstreams of a connector instance.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


